#!/usr/bin/env python

"""
User profile management.

Copyright (C) 2015 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.config import PREFERENCES_DIR
from imiptools.filesys import fix_permissions, FileBase
from os.path import exists, isdir
from os import makedirs

class Preferences(FileBase):

    "A simple preferences file manager."

    def __init__(self, user, store_dir=None):
        FileBase.__init__(self, store_dir or PREFERENCES_DIR)
        self.user = user

    def get(self, name, default=None):

        """
        Return the value for 'name', with absent entries providing a default of
        None or any indicated 'default'.
        """

        try:
            return self[name]
        except KeyError:
            return default

    def get_all(self, names):

        """
        Return a dictionary containing values for entries having the given
        'names'. Absent entries for names are omitted without error.
        """

        d = {}
        for name in names:
            value = self.get(name)
            if value is not None:
                d[name] = value
        return d

    def has_key(self, name):

        "Return whether an entry exists for 'name'."

        try:
            self[name]
            return True
        except KeyError:
            return False

    def __getitem__(self, name):

        "Return the value for 'name', raising a KeyError if absent."

        filename = self.get_object_in_store(self.user, name)
        if not filename or not exists(filename):
            raise KeyError, name

        f = open(filename)
        try:
            return f.read().strip()
        finally:
            f.close()

    def __setitem__(self, name, value):

        "Set for 'name' the given 'value'."

        filename = self.get_object_in_store(self.user, name)
        if not filename:
            return False

        f = open(filename, "w")
        try:
            f.write(value)
        finally:
            f.close()
            fix_permissions(filename)

        return True

# vim: tabstop=4 expandtab shiftwidth=4
